# Managed Skill: write-pytest

- **Source**: /Users/tomas/Documents/workspace/repos/cursor-skills
- **Installed at**: 2026-03-14
- **Target**: project-level (/Users/tomas/Documents/workspace/repos/quantum-money/.cursor/skills/)

## Installation Answers

| Question | Answer |
|---|---|
| Q1 — Install companion test-patterns Cursor rule? | Yes, installed to `.cursor/rules/test-patterns.mdc` |
